@@ -1,5 +1,3 @@
-context("construction")
-
 test_that("construction for geo_list + geo_list works as expected", {
   skip_on_cran()
 
@@ -9,9 +7,9 @@ test_that("construction for geo_list + geo_list works as expected", {
   b <- geojson_list(vecs, geometry = "polygon")
   ab <- a + b
 
-  expect_is(a, "geo_list")
-  expect_is(b, "geo_list")
-  expect_is(ab, "geo_list")
+  expect_s3_class(a, "geo_list")
+  expect_s3_class(b, "geo_list")
+  expect_s3_class(ab, "geo_list")
   expect_equal(
     as.character(jsonlite::toJSON(unclass(ab))),
     "{\"type\":[\"FeatureCollection\"],\"features\":[{\"type\":[\"Feature\"],\"geometry\":{\"type\":[\"Point\"],\"coordinates\":[-99.74,32.45]},\"properties\":{}},{\"type\":[\"Feature\"],\"geometry\":{\"type\":[\"Polygon\"],\"coordinates\":[[[100,0],[101,0],[101,1],[100,1],[100,0]]]},\"properties\":[]}]}"
@@ -26,9 +24,9 @@ test_that("construction for json + json works as expected", {
   d <- geojson_json(vecs, geometry = "polygon")
   cd <- c + d
 
-  expect_is(c, "json")
-  expect_is(d, "json")
-  expect_is(cd, "json")
+  expect_s3_class(c, "json")
+  expect_s3_class(d, "json")
+  expect_s3_class(cd, "json")
   expect_equal(
     as.character(cd),
     "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"geometry\":{\"type\":\"Point\",\"coordinates\":[-99.74,32.45]},\"properties\":{}},{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[100,0],[101,0],[101,1],[100,1],[100,0]]]},\"properties\":[]}]}"
